import React, { useState, useEffect } from 'react';
import { csv, format, timeParse } from 'd3';

const csvUrl = "https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_covid19_deaths_global.csv";

const sum = (accumulator, currentValue) => accumulator + currentValue;

const parseDay = timeParse('%m/%d/%y');

const transform = (rawData) => {
  
  // Filter out rows that represent provinces or states.
  const countriesData = rawData.filter(d => !d['Province/State']);
  
  // Get timeseries data for each country.
  const days = rawData.columns.slice(4);
  
  return countriesData.map(countryRow => {
    const countryName = countryRow['Country/Region'];
    
    return days.map(day => (
      {
        country: countryName,
        date: parseDay(day),
        deathTotal: +countryRow[day]
      }
    ));
  });
};
  
export const useData = () => {
  const [data, setData] = useState();
  
  useEffect(() => {
    csv(csvUrl).then(rawData => {
      setData(transform(rawData));
    });
  }, []);
  
  return data;
};